[U-Boot] [PATCH 4/4] test/fs: replace deprecated "sb" command with "host"

Stefan Brüns stefan.bruens at rwth-aachen.de
Wed Aug 10 00:44:46 CEST 2016


Signed-off-by: Stefan Brüns <stefan.bruens at rwth-aachen.de>
---
 test/fs/fs-test.sh | 40 ++++++++++++++++++++--------------------
 1 file changed, 20 insertions(+), 20 deletions(-)

diff --git a/test/fs/fs-test.sh b/test/fs/fs-test.sh
index 171b1de..82e91b0 100755
--- a/test/fs/fs-test.sh
+++ b/test/fs/fs-test.sh
@@ -6,14 +6,14 @@
 #
 
 # Invoke this test script from U-Boot base directory as ./test/fs/fs-test.sh
 # It currently tests the fs/sb and native commands for ext4 and fat partitions
 # Expected results are as follows:
 # EXT4 tests:
 # fs-test.sb.ext4.out: Summary: PASS: 17 FAIL: 2
 # fs-test.ext4.out: Summary: PASS: 10 FAIL: 9
 # fs-test.fs.ext4.out: Summary: PASS: 10 FAIL: 9
 # FAT tests:
 # fs-test.sb.fat.out: Summary: PASS: 17 FAIL: 2
 # fs-test.fat.out: Summary: PASS: 19 FAIL: 0
 # fs-test.fs.fat.out: Summary: PASS: 19 FAIL: 0
 # Total Summary: TOTAL PASS: 92 TOTAL FAIL: 22
@@ -155,10 +155,10 @@ function fname_for_write() {
 # 2nd parameter is file system type - fat/ext4
 # 3rd parameter is name of small file
 # 4th parameter is name of big file
 # 5th parameter is fs/nonfs/sb - to dictate generic fs commands or
 # otherwise or sb hostfs
 # 6th parameter is the directory path for the files. Its "" for generic
 # fs and ext4/fat and full patch for sb hostfs
 # UBOOT is set in env
 function test_image() {
 	addr="0x01000008"
@@ -192,8 +192,8 @@ function test_image() {
 		SUFFIX=" 0:0"
 		;;
 
-		sb)
-		PREFIX="sb "
+		host)
+		PREFIX="host "
 		WRITE="save"
 		SUFFIX="fs -"
 		;;
@@ -217,17 +217,17 @@ function test_image() {
 
 	# In u-boot commands, <interface> stands for host or hostfs
 	# hostfs maps to the host fs.
-	# host maps to the "sb bind" that we do
+	# host maps to the "host bind" that we do
 
 	$UBOOT << EOF
-sb=$5
-setenv bind 'if test "\$sb" != sb; then sb bind 0 "$1"; fi'
+host=$5
+setenv bind 'if test "\$host" != host; then host bind 0 "$1"; fi'
 run bind
 # Test Case 1 - ls
 ${PREFIX}ls host${SUFFIX} $6
 #
-# We want ${PREFIX}size host 0:0 $3 for host commands and
-# sb size hostfs - $3 for hostfs commands.
+# We want ${PREFIX}size host 0:0 $3 for fs/nonfs commands and
+# host size hostfs - $3 for host commands.
 # 1MB is 0x0010 0000
 # Test Case 2 - size of small file
 ${PREFIX}size host${SUFFIX} $FILE_SMALL
@@ -521,9 +521,9 @@ prepare_env
 TOTAL_FAIL=0
 TOTAL_PASS=0
 
 # In each loop, for a given file system image, we test both the
 # fs command, like load/size/write, the file system specific command
 # like: ext4load/ext4size/ext4write and the sb load/ls/save commands.
 for fs in ext4 fat; do
 
 	echo "Creating $fs image if not already present."
@@ -531,11 +531,11 @@ for fs in ext4 fat; do
 	MD5_FILE_FS="${MD5_FILE}.${fs}"
 	create_image $IMAGE $fs
 
 	# sb commands test
 	echo "Creating files in $fs image if not already present."
 	create_files $IMAGE $MD5_FILE_FS
 
 	# Lets mount the image and test sb hostfs commands
 	mkdir -p "$MOUNT_DIR"
 	if [ "$fs" = "fat" ]; then
 		uid="uid=`id -u`"
@@ -545,8 +545,8 @@ for fs in ext4 fat; do
 	sudo mount -o loop,rw,$uid "$IMAGE" "$MOUNT_DIR"
 	sudo chmod 777 "$MOUNT_DIR"
 
-	OUT_FILE="${OUT}.sb.${fs}.out"
-	test_image $IMAGE $fs $SMALL_FILE $BIG_FILE sb `pwd`/$MOUNT_DIR \
+	OUT_FILE="${OUT}.host.${fs}.out"
+	test_image $IMAGE $fs $SMALL_FILE $BIG_FILE host `pwd`/$MOUNT_DIR \
 		> ${OUT_FILE} 2>&1
 	sudo umount "$MOUNT_DIR"
 	rmdir "$MOUNT_DIR"
@@ -6,14 +6,14 @@
 
 # Invoke this test script from U-Boot base directory as ./test/fs/fs-test.sh
-# It currently tests the fs/sb and native commands for ext4 and fat partitions
+# It currently tests the host and native commands for ext4 and fat partitions
 # Expected results are as follows:
 # EXT4 tests:
@@ -6,14 +6,14 @@
 # Expected results are as follows:
 # EXT4 tests:
-# fs-test.sb.ext4.out: Summary: PASS: 17 FAIL: 2
+# fs-test.host.ext4.out: Summary: PASS: 19 FAIL: 0
 # fs-test.ext4.out: Summary: PASS: 10 FAIL: 9
 # fs-test.fs.ext4.out: Summary: PASS: 10 FAIL: 9
@@ -6,14 +6,14 @@
 # fs-test.fs.ext4.out: Summary: PASS: 10 FAIL: 9
 # FAT tests:
-# fs-test.sb.fat.out: Summary: PASS: 17 FAIL: 2
+# fs-test.host.fat.out: Summary: PASS: 19 FAIL: 0
 # fs-test.fat.out: Summary: PASS: 19 FAIL: 0
 # fs-test.fs.fat.out: Summary: PASS: 19 FAIL: 0
@@ -155,10 +155,10 @@ function fname_for_write() {
 # 3rd parameter is name of small file
 # 4th parameter is name of big file
-# 5th parameter is fs/nonfs/sb - to dictate generic fs commands or
-# otherwise or sb hostfs
+# 5th parameter is fs/nonfs/host - to dictate generic fs commands or
+# otherwise or host
 # 6th parameter is the directory path for the files. Its "" for generic
@@ -155,10 +155,10 @@ function fname_for_write() {
 # 6th parameter is the directory path for the files. Its "" for generic
-# fs and ext4/fat and full patch for sb hostfs
+# fs and ext4/fat and full path for host
 # UBOOT is set in env
 function test_image() {
@@ -521,9 +521,9 @@ prepare_env
 TOTAL_PASS=0
 
-# In each loop, for a given file system image, we test both the
-# fs command, like load/size/write, the file system specific command
-# like: ext4load/ext4size/ext4write and the sb load/ls/save commands.
+# In each loop, for a given file system image, we test both the fs command,
+# like ls/size/load/save, the file system specific command, like
+# ext4ls/ext4size/ext4load/ext4write and the host ls/size/load/save commands.
 for fs in ext4 fat; do
 
@@ -531,11 +531,11 @@ for fs in ext4 fat; do
 	create_image $IMAGE $fs
 
-	# sb commands test
+	# host commands test
 	echo "Creating files in $fs image if not already present."
 	create_files $IMAGE $MD5_FILE_FS
@@ -531,11 +531,11 @@ for fs in ext4 fat; do
 	create_files $IMAGE $MD5_FILE_FS
 
-	# Lets mount the image and test sb hostfs commands
+	# Lets mount the image and test host commands
 	mkdir -p "$MOUNT_DIR"
 	if [ "$fs" = "fat" ]; then
-- 
2.9.2



More information about the U-Boot mailing list